\name{adcoord}
\alias{adcoord}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Asymmetric discriminant coordinates}
\description{
  Asymmetric discriminant coordinates as defined
  in Hennig (2003). Asymmetric discriminant projection means that there
  are two classes, one of which is treated as the homogeneous class
  (i.e., it should appear homogeneous and separated in the resulting projection)
  while the other may be heterogeneous. 
  The principle is to maximize the ratio between the projection of a between
  classes separation matrix and the projection of the covariance matrix
  within the homogeneous class.  
}
\usage{
adcoord(xd, clvecd, clnum=1)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{xd}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{integer vector of class numbers; length must equal
    \code{nrow(xd)}.}
  \item{clnum}{integer. Number of the homogeneous class.}
}
\details{
  The square root of the homogeneous classes covariance matrix
  is inverted by use of
  \code{\link{tdecomp}}, which can be expected to give
  reasonable results for singular within-class covariance matrices.
}
% \details{
% }
\value{
  List with the following components
  \item{ev}{eigenvalues in descending order.}
  \item{units}{columns are coordinates of projection basis vectors.
  New points \code{x} can be projected onto the projection basis vectors
  by \code{x \%*\% units}}
  \item{proj}{projections of \code{xd} onto \code{units}.} 
}
\references{
  Hennig, C. (2003) Symmetric, asymmetric, and robust linear dimension
  reduction for classification, submitted,
  \url{http://stat.ethz.ch/Research-Reports/108.html}.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{plotcluster}} for straight forward discriminant plots.
  \code{\link{discrproj}} for alternatives.
  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
  set.seed(4634)
  face <- rFace(600,dMoNo=2,dNoEy=0)
  grface <- as.integer(attr(face,"grouping"))
  adcf <- adcoord(face,grface==2)
  adcf2 <- adcoord(face,grface==4)
  plot(adcf$proj,col=1+(grface==2))
  plot(adcf2$proj,col=1+(grface==4))
  # ...done in one step by function plotcluster.
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line



\eof
\name{ancoord}
\alias{ancoord}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Asymmetric neighborhood based discriminant coordinates}
\description{
  Asymmetric neighborhood based discriminant coordinates as defined
  in Hennig (2003). Asymmetric discriminant projection means that there
  are two classes, one of which is treated as the homogeneous class
  (i.e., it should appear homogeneous and separated in the resulting projection)
  while the other may be heterogeneous. 
  The principle is to maximize the ratio between the projection of a between
  classes covariance matrix, which is defined by averaging the
  between classes covariance matrices in the neighborhoods of the points
  of the homogeneous class and the projection of the covariance matrix
  within the homogeneous class.  
}
\usage{
ancoord(xd, clvecd, clnum=1, nn=50, method="mcd", countmode=1000, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{xd}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{integer vector of class numbers; length must equal
    \code{nrow(xd)}.}
  \item{clnum}{integer. Number of the homogeneous class.}
  \item{nn}{integer. Number of points which belong to the neighborhood
    of each point (including the point itself).}
  \item{method}{one of
    "mve", "mcd" or "classical". Covariance matrix used within the
    homogeneous class.
    "mcd" and "mve" are robust covariance matrices as implemented
    in \code{\link{cov.rob}}. "classical" refers to the classical
    covariance matrix.}
  \item{countmode}{optional positive integer. Every \code{countmode}
    algorithm runs \code{ancoord} shows a message.}
  \item{...}{no effect}
}
\details{
  The square root of the homogeneous classes covariance matrix
  is inverted by use of
  \code{\link{tdecomp}}, which can be expected to give
  reasonable results for singular within-class covariance matrices.
}
% \details{
% }
\value{
  List with the following components
  \item{ev}{eigenvalues in descending order.}
  \item{units}{columns are coordinates of projection basis vectors.
  New points \code{x} can be projected onto the projection basis vectors
  by \code{x \%*\% units}}
  \item{proj}{projections of \code{xd} onto \code{units}.} 
}
\references{
  Hennig, C. (2003) Symmetric, asymmetric, and robust linear dimension
  reduction for classification, submitted,
  \url{http://stat.ethz.ch/Research-Reports/108.html}.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{plotcluster}} for straight forward discriminant plots.
  \code{\link{discrproj}} for alternatives.
  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
  set.seed(4634)
  face <- rFace(600,dMoNo=2,dNoEy=0)
  grface <- as.integer(attr(face,"grouping"))
  ancf <- ancoord(face,grface==1)
  ancf2 <- ancoord(face,grface==4)
  plot(ancf$proj,col=1+(grface==1))
  plot(ancf2$proj,col=1+(grface==4))
  # ...done in one step by function plotcluster.
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line



\eof
\name{awcoord}
\alias{awcoord}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Asymmetric weighted discriminant coordinates}
\description{
  Asymmetric weighted discriminant coordinates as defined
  in Hennig (2003). Asymmetric discriminant projection means that there
  are two classes, one of which is treated as the homogeneous class
  (i.e., it should appear homogeneous and separated in the resulting projection)
  while the other may be heterogeneous. 
  The principle is to maximize the ratio between the projection of a between
  classes separation matrix and the projection of the covariance matrix
  within the homogeneous class. Points are weighted according to their
  (robust) Mahalanobis distance to the homogeneous class. 
}
\usage{
awcoord(xd, clvecd, clnum=1, mahal="square", method="classical",
                     clweight=switch(method,classical=FALSE,TRUE),
                     alpha=0.99, subsample=0, countmode=1000, ...) 
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{xd}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{integer vector of class numbers; length must equal
    \code{nrow(xd)}.}
  \item{clnum}{integer. Number of the homogeneous class.}
  \item{mahal}{"md" or "square". If "md", the points are weighted by the
    square root of the \code{alpha}-quantile of the
    corresponding chi squared distribution
    over the roots of their Mahalanobis distance to the
    homogeneous class, unless
    this is smaller than 1. If "square" (which is recommended), the
    (originally squared) Mahalanobis distance and the
    unrooted quantile is used.}
  \item{method}{one of
    "mve", "mcd" or "classical". Covariance matrix used within the
    homogeneous class and for the computation of the Mahalanobis distances.
    "mcd" and "mve" are robust covariance matrices as implemented
    in \code{\link{cov.rob}}. "classical" refers to the classical
    covariance matrix.}
  \item{clweight}{logical. If \code{FALSE}, only the points of the
    heterogeneous class are weighted. This, together with
    \code{method="classical"}, computes AWC as defined in Hennig (2003). If
    \code{TRUE}, all points are weighted. This, together with
    \code{method="mcd"}, computes ARC as defined in Hennig (2003).}
  \item{alpha}{numeric between 0 and 1. The corresponding quantile of
    the chi squared distribution is used for the downweighting
    of points. Points with a smaller Mahalanobis distance to the
    homogeneous class get full weight.}
  \item{subsample}{integer. If 0, all points are used. Else, only a
    subsample of \code{subsample} of the points is used.}
  \item{countmode}{optional positive integer. Every \code{countmode}
    algorithm runs \code{awcoord} shows a message.}
  \item{...}{no effect}
}
\details{
  The square root of the homogeneous classes covariance matrix
  is inverted by use of
  \code{\link{tdecomp}}, which can be expected to give
  reasonable results for singular within-class covariance matrices.
}
% \details{
% }
\value{
  List with the following components
  \item{ev}{eigenvalues in descending order.}
  \item{units}{columns are coordinates of projection basis vectors.
  New points \code{x} can be projected onto the projection basis vectors
  by \code{x \%*\% units}}
  \item{proj}{projections of \code{xd} onto \code{units}.} 
}
\references{
  Hennig, C. (2003) Symmetric, asymmetric, and robust linear dimension
  reduction for classification, submitted,
  \url{http://stat.ethz.ch/Research-Reports/108.html}.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{plotcluster}} for straight forward discriminant plots.
  \code{\link{discrproj}} for alternatives.
  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
  set.seed(4634)
  face <- rFace(600,dMoNo=2,dNoEy=0)
  grface <- as.integer(attr(face,"grouping"))
  awcf <- awcoord(face,grface==1)
  awcf2 <- ancoord(face,grface==1, method="mcd")
  plot(awcf$proj,col=1+(grface==1))
  plot(awcf2$proj,col=1+(grface==1))
  # ...done in one step by function plotcluster.
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line



\eof
\name{batcoord}
\alias{batcoord}
\alias{batvarcoord}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Bhattacharyya discriminant projection}
\description{
  Computes Bhattacharyya discriminant projection coordinates
  as described in Fukunaga (1990), p. 455 ff.
}
\usage{
batcoord(xd, clvecd, clnum=1, dom="mean")
batvarcoord(xd, clvecd, clnum=1)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{xd}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{integer or logical vector of class numbers; length must equal
    \code{nrow(xd)}.}
  \item{clnum}{integer, one of the values of \code{clvecd}, if this is
    an integer vector. Bhattacharyya projections can only be computed if
    there are only two classes in the dataset. \code{clnum} is the number
    of one of the two classes. All the points indicated by other values
    of \code{clvecd} are interpreted as the second class.}
  \item{dom}{string. \code{dom="mean"} means that the discriminant
    coordinate for the group means is computed as the first projection
    direction by
    \code{\link{discrcoord}} (option \code{pool="equal"}; both classes
    have the same weight for computing the within-class covariance
    matrix). Then the data is projected into a subspace orthogonal
    (w.r.t. the within-class covariance) to the
    discriminant coordinate, and the projection coordinates to maximize
    the differences in variance are computed. \cr
    \code{dom="variance"} means that the projection coordinates
    maximizing the difference in variances are computed. Then they are
    ordered with respect to the Bhattacharyya distance, which takes also
    the mean differences into account. Both procedures are implemented
    as described in Fukunaga (1990).}
}
\details{
\code{batvarcoord} computes the optimal projection coordinates with
respect to the difference in variances. \code{batcoord} combines the
differences in mean and variance as explained for the argument \code{dom}.
}
\value{
  \code{batcoord} returns a list with the components \code{ev, rev,
    units, proj}. \code{batvarcoord} returns a list with the components
  \code{ev, rev, units, proj, W, S1, S2}. 
  \item{ev}{vector of eigenvalues. If \code{dom="mean"}, then first eigenvalue
    from \code{\link{discrcoord}}. Further eigenvalues are of
  \eqn{S_1^{-1}S_2}, where \eqn{S_i} is the covariance matrix of class
  i. For \code{batvarcoord} or
  if \code{dom="variance"}, all eigenvalues come from
  \eqn{S_1^{-1}S_2} and are ordered by \code{rev}.}
\item{rev}{for \code{batcoord}:
  vector of projected Bhattacharyya distances (Fukunaga
  (1990), p. 99). Determine quality of the projection coordinates.
  For \code{batvarcoord}: vector of amount of projected difference in
  variances.}
  \item{units}{columns are coordinates of projection basis vectors.
  New points \code{x} can be projected onto the projection basis vectors
  by \code{x \%*\% units}.}
  \item{proj}{projections of \code{xd} onto \code{units}.} 

  \item{W}{matrix \eqn{S_1^{-1}S_2}.}
  \item{S1}{covariance matrix of the first class.}    
  \item{S2}{covariance matrix of the second class.}    
}
\references{
  Fukunaga, K. (1990). \emph{Introduction to Statistical Pattern
    Recognition} (2nd ed.). Boston: Academic Press.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{
  \code{\link{plotcluster}} for straight forward discriminant plots.
  
  \code{\link{discrcoord}} for discriminant coordinates.

  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
set.seed(4634)
face <- rFace(600,dMoNo=2,dNoEy=0)
grface <- as.integer(attr(face,"grouping"))
bcf2 <- batcoord(face,grface==2)
plot(bcf2$proj,col=1+(grface==2))
bcfv2 <- batcoord(face,grface==2,dom="variance")
plot(bcfv2$proj,col=1+(grface==2))
bcfvv2 <- batvarcoord(face,grface==2)
plot(bcfvv2$proj,col=1+(grface==2))
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line

\eof
\name{c.weight}
\alias{c.weight}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Weight function for AWC}
\description{
  For use in \code{awcoord} only.
}
\usage{
c.weight(x, ca) 

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{numerical.}
  \item{ca}{numerical.}
}
% \details{
% }
\value{
  \code{ca/x} if smaller than 1, else 1.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{awcoord}}
}

\examples{
  c.weight(4,1)
}
\keyword{arith}% at least one, from doc/KEYWORDS



\eof
\name{can}
\alias{can}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Generation of the tuning constant for regression fixed point clusters}
\description{
  Generates tuning constants \code{ca}
  for \code{\link{fixreg}} dependent on
  the number of points and variables of the dataset.
  
  Only thought for use in \code{\link{fixreg}}.
  
}
\usage{
can(n, p)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{positive integer. Number of points.}
  \item{p}{positive integer. Number of independent variables.}
}
\details{
  The formula is
  \eqn{3+33/(n*2^{-(p-1)/2})^{1/3}+2900000/(n*2^{-(p-1)/2})^3}. For
  justification cf. Hennig (2002).
}
\value{
  A number.
}
\references{
  Hennig, C. (2002) Fixed point clusters for linear regression:
  computation and comparison, \emph{Journal of
    Classification} 19, 249-276.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{fixreg}}}

\examples{
  can(429,3)
}
\keyword{arith}% at least one, from doc/KEYWORDS

\eof
\name{clusexpect}
\alias{clusexpect}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Expected value of the number of times a fixed point
  cluster is found}
\description{
  A rough approximation of the expectation of the number of times a well
  separated fixed point
  cluster (FPC) of size \code{n} is found in \code{ir} fixed point
  iterations of \code{\link{fixreg}}.
}
\usage{
clusexpect(n, p, cn, ir)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{positive integer. Total number of points.}
  \item{p}{positive integer. Number of independent variables.}
  \item{cn}{positive integer smaller or equal to \code{n}.
    Size of the FPC.}
  \item{ir}{positive integer. Number of fixed point iterations.}
}
\details{
  The approximation is based on the assumption that a well separated FPC
  is found iff all \code{p+2} points of the initial coinfiguration come
  from the FPC. The value is \code{ir} times the probability for
  this. For a discussion of this assumption cf. Hennig (2002).
}
\value{
  A number.
}

\references{
  Hennig, C. (2002) Fixed point clusters for linear regression:
  computation and comparison, \emph{Journal of
    Classification} 19, 249-276.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{fixreg}}}

\examples{
  clusexpect(500,4,150,2000)
}
\keyword{univar}% at least one, from doc/KEYWORDS
\keyword{cluster}
\eof
\name{cmahal}
\alias{cmahal}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Generation of tuning constant for Mahalanobis fixed point clusters.}
\description{
  Generates tuning constants \code{ca}
  for \code{\link{fixmahal}} dependent on
  the number of points and variables of the current fixed point cluster
  (FPC).
  
  This is experimental and only thought for use in \code{\link{fixmahal}}.
}
\usage{
cmahal(n, p, nmin, cmin, nc1, c1 = cmin, q = 1)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{positive integer. Number of points.}
  \item{p}{positive integer. Number of variables.}
  \item{nmin}{integer larger than 1. Smallest number of points for which
    \code{ca} is computed. For smaller FPC sizes, \code{ca} is set to
    the value for \code{nmin}.}
  \item{cmin}{positive number. Minimum value for \code{ca}.}
  \item{nc1}{positive integer. Number of points at which \code{ca=c1}.}
  \item{c1}{positive numeric. Tuning constant for \code{cmahal}.
    Value for \code{ca} for FPC size equal to \code{nc1}.}
  \item{q}{numeric between 0 and 1. 1 for steepest possible descent of
    \code{ca} as function of the FPC size. Should presumably always be 1.}
}
\details{
  Some experiments suggest that the tuning constant \code{ca} should
  decrease with increasing FPC size and increase with increasing
  \code{p} in \code{\link{fixmahal}}. This is to prevent too small
  meaningless FPCs while maintaining the significant larger
  ones. \code{cmahal} with \code{q=1} computes \code{ca} in such a way
  that as long as \code{ca>cmin}, the decrease in \code{n} is as steep
  as possible in order to maintain the validity of the convergence
  theorem in Hennig and Christlieb (2002).
}
\value{
  A numeric vector of length \code{n}, giving the values for \code{ca}
  for all FPC sizes smaller or equal to \code{n}.
}
\references{
  Hennig, C. and Christlieb, N. (2002) Validating visual clusters in
  large datasets: Fixed point clusters of spectral features,
  \emph{Computational Statistics and Data Analysis} 40, 723-739.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{fixmahal}}}

\examples{
  plot(1:100,cmahal(100,3,nmin=5,cmin=qchisq(0.99,3),nc1=90),
       xlab="FPC size", ylab="cmahal")
}
\keyword{cluster}% at least one, from doc/KEYWORDS

\eof
\name{con.comp}
\alias{con.comp}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Connectivity components of an undirected graph}
\description{
  Computes the connectivity components of an undirected graph from a
  matrix giving the edges.
}
\usage{
con.comp(comat)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{comat}{a symmetric logical or 0-1 matrix, where \code{comat[i,j]=TRUE}
    means that there is an edge between vertices \code{i} and
    \code{j}. The diagonal is ignored.}
}
\details{
  The "depth-first search" algorithm of Cormen, Leiserson and Rivest
  (1990, p. 477) is used.
}
\value{
  An integer vector, giving the number of the connectivity component for
  each vertice.
}
\references{
  Cormen, T. H., Leiserson, C. E. and Rivest, R. L. (1990), \emph{Introduction
    to Algorithms}, Cambridge: MIT Press.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{hclust}}, \code{\link{cutree}} for cutted single linkage
  trees (often equivalent).
}

\examples{
  set.seed(1000)
  x <- rnorm(20)
  m <- matrix(0,nrow=20,ncol=20)
  for(i in 1:20)
    for(j in 1:20)
      m[i,j] <- abs(x[i]-x[j])
  d <- m<0.2
  cc <- con.comp(d)
  max(cc) # number of connectivity components
  plot(x,cc)
  # The same should be produced by
  # cutree(hclust(as.dist(m),method="single"),h=0.2).
}
\keyword{array}% at least one, from doc/KEYWORDS
\keyword{cluster}% __ONLY ONE__ keyword per line


\eof
\name{cov.wml}
\alias{cov.wml}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Weighted Covariance Matrices (Maximum Likelihood)}
\description{
     Returns a list containing estimates of the weighted covariance
     matrix and the mean of the data, and optionally of the (weighted)
     correlation matrix. The
     covariance matrix is divided by the sum of the weights,
     corresponding to \code{n} and the ML-estimator in the case of equal
     weights, as opposed to \code{n-1} for \code{\link{cov.wt}}. 
}
\usage{
cov.wml(x, wt = rep(1/nrow(x), nrow(x)), cor = FALSE, center = TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{a matrix or data frame.  As usual, rows are observations and
          columns are variables.}
  \item{wt}{a non-negative and non-zero vector of weights for each
          observation.  Its length must equal the number of rows of
          \code{x}.}
  \item{cor}{A logical indicating whether the estimated correlation
          weighted matrix will be returned as well.}
  \item{center}{Either a logical or a numeric vector specifying the centers
          to be used when computing covariances.  If \code{TRUE}, the
          (weighted) mean of each variable is used, if `\code{FALSE}, zero is
          used.  If \code{center} is numeric, its length must equal the
          number of columns of \code{x}.}
}
\value{
  A list containing the following named components:
  \item{cov}{the estimated (weighted) covariance matrix.}
  \item{center}{an estimate for the center (mean) of the data.}
  \item{n.obs}{the number of observations (rows) in \code{x}.}
  \item{wt}{the weights used in the estimation.  Only returned if given
    as an argument.}
  \item{cor}{the estimated correlation matrix.  Only returned if `cor' is
          `TRUE'.}
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{cov.wt}}, \code{\link{cov}}, \code{\link{var}}}

\examples{
  x <- c(1,2,3,4,5,6,7,8,9,10)
  y <- c(1,2,3,8,7,6,5,8,9,10)
  cov.wml(cbind(x,y),wt=c(0,0,0,1,1,1,1,1,0,0))
  cov.wt(cbind(x,y),wt=c(0,0,0,1,1,1,1,1,0,0))
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\eof
\name{discrcoord}
\alias{discrcoord}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Discriminant coordinates/canonical variates}
\description{
  Computes discriminant coordinates, sometimes referred to as "canonical
  variates" as described in Seber (1984).
}
\usage{
discrcoord(xd, clvecd, pool = "n", ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{xd}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{integer vector of class numbers; length must equal
    \code{nrow(xd)}.}
  \item{pool}{string. Determines how the within classes
    covariance is pooled. "n" means that the class covariances are
    weighted corresponding to the number of points in each class
    (default). "equal" means that all classes get equal weight.}
  \item{...}{no effect}
}
\details{
  The matrix T (see Seber (1984), p. 270) is inverted by use of
  \code{\link{tdecomp}}, which can be expected to give
  reasonable results for singular within-class covariance matrices.
}
\value{
  List with the following components
  \item{ev}{eigenvalues in descending order.}
  \item{units}{columns are coordinates of projection basis vectors.
  New points \code{x} can be projected onto the projection basis vectors
  by \code{x \%*\% units}}
  \item{proj}{projections of \code{xd} onto \code{units}.} 
}
\references{
  Seber, G. A. F. (1984). \emph{Multivariate Observations}. New York: Wiley.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{plotcluster}} for straight forward discriminant plots.
  
  \code{\link{batcoord}} for discriminating projections for two classes,
  so that also the differences in variance are shown (\code{discrcoord} is
  based only on differences in mean).

  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
  set.seed(4634)
  face <- rFace(600,dMoNo=2,dNoEy=0)
  grface <- as.integer(attr(face,"grouping"))
  dcf <- discrcoord(face,grface)
  plot(dcf$proj,col=grface)
  # ...done in one step by function plotcluster.
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line



\eof
\name{discrproj}
\alias{discrproj}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Linear dimension reduction for classification}
\description{
   An interface for ten methods of linear dimension reduction in order
   to separate the groups optimally in the projected data. Includes
   classical discriminant coordinates, methods to project differences in
   mean and covariance structure, asymmetric methods (separation of a
   homogeneous class from a heterogeneous one), local neighborhood-based
   methods and methods based on robust covariance matrices.
}
\usage{
 discrproj(x, clvecd, method="awc", clnum=1, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{vector of class numbers which can be coerced into
    integers; length must equal
    \code{nrow(xd)}.}
  \item{method}{one of
    \describe{
      \item{"dc"}{usual discriminant coordinates, see \code{\link{discrcoord}},}
      \item{"bc"}{Bhattacharyya coordinates, first coordinate showing
	mean differences, second showing covariance matrix differences,
	see \code{\link{batcoord}},}
      \item{"vbc"}{variance dominated Bhattacharyya coordinates,
	see \code{\link{batcoord}},}
      \item{"mvdc"}{added meana and variance differences optimizing
	coordinates, see \code{\link{mvdcoord}},}
      \item{"adc"}{asymmetric discriminant coordinates, see
	\code{\link{adcoord}},}
      \item{"awc"}{asymmetric discriminant coordinates with weighted
	observations, see \code{\link{awcoord}},}
      \item{"arc"}{asymmetric discriminant coordinates with weighted
	observations and robust MCD-covariance matrix,
	see \code{\link{awcoord}},}
      \item{"nc"}{neighborhood based coordinates,
	see \code{\link{ncoord}},}
      \item{"wnc"}{neighborhood based coordinates with weighted neighborhoods,
	see \code{\link{ncoord}},}
      \item{"anc"}{asymmetric neighborhood based coordinates,
	see \code{\link{ancoord}}.}
    }
    Note that "bc", "vbc", "adc", "awc", "arc" and "anc" assume that
    there are only two classes.}
  \item{clnum}{integer. Number of the class which is attempted to plot
    homogeneously by "asymmetric methods", which are the methods
    assuming that there are only two classes, as indicated above.} 
  \item{...}{additional parameters passed to the
    projection methods.}
}
% \details{
% }

\value{
  \code{discrproj} returns the output of the chosen projection method,
  which is a list with at least the components \code{ev, units, proj}.
  For detailed informations see the help pages of the projection methods.
  \item{ev}{eigenvalues in descending order, usually indicating portion
    of information in the corresponding direction.}
  \item{units}{columns are coordinates of projection basis vectors.
  New points \code{x} can be projected onto the projection basis vectors
  by \code{x \%*\% units}}
  \item{proj}{projections of \code{xd} onto \code{units}.} 
}
  
\references{
  Hennig, C. (2003) Symmetric, asymmetric, and robust linear dimension
  reduction for classification, submitted,
  \url{http://stat.ethz.ch/Research-Reports/108.html}.
  
  Seber, G. A. F. (1984). \emph{Multivariate Observations}. New York: Wiley.

  Fukunaga (1990). \emph{Introduction to Statistical Pattern
  Recognition} (2nd ed.). Boston: Academic Press.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{
  \code{\link{discrcoord}}, \code{\link{batcoord}},
  \code{\link{mvdcoord}}, \code{\link{adcoord}},
  \code{\link{awcoord}}, \code{\link{ncoord}},
  \code{\link{ancoord}}.

  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
set.seed(4634)
face <- rFace(600,dMoNo=2,dNoEy=0)
grface <- as.integer(attr(face,"grouping"))
discrproj(face,grface, method="nc")$units
discrproj(face,grface, method="wnc")$units
discrproj(face,grface==1, method="arc")$units
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line



\eof
\name{fixmahal}
\alias{fixmahal}
\alias{summary.mfpc}
\alias{plot.mfpc}
\alias{fpclusters.mfpc}
\alias{print.summary.mfpc}
\alias{print.mfpc}
\alias{fpmi}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Mahalanobis Fixed Point Clusters}
\description{
  Computes Mahalanobis fixed point clusters (FPCs), i.e.,
  subsets of the data, which consist exactly of the
  non-outliers w.r.t. themselves, and may be interpreted
  as generated from a homogeneous normal population.
  FPCs may
  overlap, are not necessarily exhausting and
  do not need a specification of the number of clusters.

  Note that while \code{fixmahal} has lots of parameters, only one (or
  few) of them have usually to be specified, cf. the examples. The
  philosophy is to allow much flexibility, but to always provide 
  sensible defaults.
}
\usage{
fixmahal(dat, n = nrow(as.matrix(dat)), p = ncol(as.matrix(dat)), 
                      method = "fuzzy", cgen = "fixed",
                      ca = NA, ca2 = NA,
                      calpha = ifelse(method=="fuzzy",0.9,0.95),
                      calpha2 = 0.99,
                      pointit = TRUE, subset = n,
                      mnc = min(floor(n/2),10+2*p), nc1 = 100+20*p,
                      startn = min(floor(n/2),ifelse(cgen=="auto",mnc,2*mnc)),
                      mer = ifelse(pointit,0.1,0), 
                      distcut = 0.85, maxit = 5*n, iter = n*1e-5,
                      init.group = list(), 
                      ind.storage = TRUE, countmode = 100, 
                      plot = "none")


\method{summary}{mfpc}(object, ...)

\method{plot}{mfpc}(x, dat, no, bw=FALSE, main=c("Representative FPC No. ",no),
                    xlab=NULL, ylab=NULL,
                    pch=NULL, col=NULL, ...)

\method{fpclusters}{mfpc}(object, dat=NA, ca=object$ca, p=object$p, ...)

fpmi(dat, n = nrow(as.matrix(dat)), p = ncol(as.matrix(dat)),
                  gv, ca, ca2, method = "classical", plot,
                  maxit = 5*n, iter = n*1e-6) 
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{dat}{something that can be coerced to a
    numerical matrix or vector. Data matrix, rows are points, columns
    are variables.
    \code{fpclusters.rfpc}
    does not need specification of \code{dat} if \code{fixmahal}
    has been run with \code{ind.storage=TRUE}.}
  \item{n}{optional positive integer.
    Number of cases.}
  \item{p}{optional positive integer.
    Number of independent variables.}
  \item{method}{a string. \code{method="classical"} means 0-1 weighting
    of observations by Mahalanobis distances and use of the classical
    normal covariance estimator. \code{method="ml"} uses the
    ML-covariance estimator (division by \code{n} instead of \code{n-1}) 
    This is used in Hennig and Christlieb (2002).
    \code{method} can also be \code{"mcd"} or \code{"mve"},
    to enforce the use of robust centers and covariance matrices, see
    \code{\link{cov.rob}}. This is experimental, not recommended at the
    moment, may be very slowly and requires library \code{lqs}.
    The default is
    \code{method="fuzzy"}, where weighted means and covariance matrices
    are used. The weights are computed by \code{\link{wfu}}, i.e., a
    function that is constant 1 for arguments smaller than \code{ca}, 0 for
    arguments larger than \code{ca2} and continuously linear in between.
    Convergence is only proven for \code{method="ml"} up to now.}  
  \item{cgen}{optional string. \code{"fixed"} means that the same tuning
    constant \code{ca} is used for all iterations. \code{"auto"} means
    that \code{ca} is generated dependently on the size of the current data
    subset in each iteration by \code{\link{cmahal}}. This is 
    experimental.}
  \item{ca}{optional positive number. Tuning constant, specifying
    required cluster
    separation. By default determined as \code{calpha}-quantile of the
    chisquared distribution with \code{p} degrees of freedom.}
  \item{ca2}{optional positive number. Second tuning constant needed if
    \code{method="fuzzy"}.
    By default determined as \code{calpha2}-quantile of the
    chisquared distribution with \code{p} degrees of freedom.}
  \item{calpha}{number between 0 and 1. See \code{ca}.}
  \item{calpha2}{number between 0 and 1, larger than \code{calpha}.
    See \code{ca2}.}
  \item{pointit}{optional logical. If \code{TRUE}, \code{subset} fixed point
    algorithms are started from initial configurations, which are built
    around single points of the dataset, cf. \code{\link{mahalconf}}.
    Otherwise, initial configurations are only specified by
    \code{init.group}.}
  \item{subset}{optional positive integer smaller or equal than \code{n}.
    Initial configurations for the fixed point algorithm
    (cf. \code{\link{mahalconf}}) are built from
    a subset of \code{subset} points from the data. No effect if
    \code{pointit=FALSE}. Default: all points.}
  \item{mnc}{optional positive integer. Minimum size of clusters
    to be reported.}
  \item{nc1}{optional positive integer. Tuning constant needed by
    \code{\link{cmahal}} to generate \code{ca} automatically. Only 
    needed for \code{cgen="auto"}.} 
  \item{startn}{optional positive integer. Size of the initial
    configurations. The default value is chosen to prevent that small 
    meaningless FPCs are found, but it should be decreased if 
    clusters of size smaller than the default value are of interest.} 
  \item{mer}{optional nonnegative number. FPCs (groups of them,
    respectively, see details)
    are only reported as stable if the ratio 
    of the number of their
    findings to their number of points exceeds \code{mer}. This holds
    under \code{pointit=TRUE} and \code{subset=n}. For \code{subset<n},
    the ratio is adjusted, but for small \code{subset}, the results
    may extremely vary and have to be taken with care.}
  \item{distcut}{optional value between 0 and 1. A similarity
    measure between FPCs, given in Hennig (2002a), and the corresponding
    Single Linkage groups of FPCs with similarity larger
    than \code{distcut} are computed.
    A single representative FPC is selected for each group.}
  \item{maxit}{optional integer. Maximum number of iterations
    per algorithm run (usually an FPC is found much earlier).}
  \item{iter}{positive number. Algorithm stops when difference between
    subsequent weight vectors is smaller than \code{iter}. Only needed
    for \code{method="fuzzy"}.}
  \item{init.group}{optional list of logical vectors of length
    \code{n}.
    Every vector indicates a starting configuration for the fixed
    point algorithm. This can be used for datasets with high
    dimension, where the vectors of \code{init.group} indicate cluster
    candidates found by graphical inspection or background
    knowledge, as in Hennig and Christlieb (2002).}
  \item{ind.storage}{optional logical. If \code{TRUE},
    then all indicator
    vectors of found FPCs are given in the value of \code{fixmahal}.
    May need lots of memory, but is a bit faster.}
  \item{countmode}{optional positive integer. Every \code{countmode}
    algorithm runs \code{fixreg} shows a message.}
  \item{plot}{optional string. If \code{"start"}, you get a scatterplot
    of the first two variables to highlight the initial configuration,
    \code{"iteration"} generates such a plot at each iteration,
    \code{"both"} does both (this may be very time consuming).
    The default is \code{"none"}.}
  \item{object}{object of class \code{mfpc}, output of \code{fixmahal}.}
  \item{x}{object of class \code{mfpc}, output of \code{fixmahal}.}
  \item{maxnc}{optional positive integer. Maximum number of FPCs
    to be reported.}
  \item{no}{positive integer. Number of the representative FPC to
    be plotted.}
  \item{bw}{optional logical. If \code{TRUE}, plot is black/white,
    FPC is
    indicated by different symbol. Else FPC is indicated red.}
  \item{main}{plot title.}
  \item{xlab}{label for x-axis. If \code{NULL}, a default text is used.}
  \item{ylab}{label for y-axis. If \code{NULL}, a default text is used.}
  \item{pch}{plotting symbol, see \code{\link{par}}.
    If \code{NULL}, the default is used.}
  \item{col}{plotting color, see \code{\link{par}}.
    If \code{NULL}, the default is used.}
  \item{gv}{logical vector (or, with \code{method="fuzzy"},
    vector of weights between 0 and 1) of length \code{n}.
    Indicates the initial
    configuration for the fixed point algorithm.} 
  \item{...}{additional parameters to be passed to \code{plot}
    (no effects elsewhere).}
}
\details{A (crisp) Mahalanobis FPC is a data subset 
  that reproduces itself under the following operation: \cr
  Compute mean and covariance matrix estimator for the data
  subset, and compute all points of the dataset for which the squared
  Mahalanobis distance is smaller than \code{ca}.\cr
  Fixed points of this operation can be considered as clusters,
  because they contain only
  non-outliers (as defined by the above mentioned procedure) and all other
  points are outliers w.r.t. the subset. \cr
  The current default is to compute fuzzy Mahalanobis FPCs, where the
  points in the subset have a membership weight between 0 and 1 and give
  rise to weighted means and covariance matrices.
  The new weights are then obtained by computing the weight function
  \code{\link{wfu}} of the squared Mahalanobis distances, i.e.,
  full weight for squared distances smaller than \code{ca}, zero
  weight for squared distances larger than \code{ca2} and 
  decreasing weights (linear function of squared distances)
  in between.\cr
  A fixed point algorithm is started from the whole dataset,
  algorithms are started from the subsets specified in
  \code{init.group}, and further algorithms are strated from further
  initial configurations as explained under \code{subset} and in the
  function \code{\link{mahalconf}}. \cr
  Usually some of the FPCs are unstable, and more than one FPC may
  correspond to the same significant pattern in the data. Therefore the
  number of FPCs is reduced: A similarity matrix is computed
  between FPCs. Similarity between sets is defined as the ratio between
  2 times size of
  intersection and the sum of sizes of both sets. The Single Linkage
  clusters (groups)
  of level \code{distcut} are computed, i.e. the connectivity
  components of the graph where edges are drawn between FPCs with
  similarity larger than \code{distcut}. Groups of FPCs whose members
  are found often enough (cf. parameter \code{mer}) are considered as
  stable enough. A representative FPC is
  chosen for every Single Linkage cluster of FPCs according to the
  maximum expectation ratio \code{ser}. \code{ser} is the ratio between
  the number of findings of an FPC and the number of points
  of an FPC, adjusted suitably if \code{subset<n}.
  Usually only the representative FPCs of stable groups
  are of interest. \cr
  The choice of the involved tuning constants is somewhat experimental
  at the moment. Hennig (2002) treats the linear regression case, which
  includes \code{fixmahal} for \code{p=1}.  See also Hennig and
  Christlieb (2002). \cr
  Generally, the default settings are recommended for
  \code{fixreg}. For large datasets, the use of
  \code{init.group} together with \code{pointit=FALSE}
  is useful. Occasionally, \code{mnc} and \code{startn} may be chosen
  smaller than the default,
  if smaller clusters are of interest, but this may lead to too many
  clusters. Decrease of
  \code{ca} will often lead to too many clusters, even for homogeneous
  data. Increase of \code{ca} will produce only very strongly
  separated clusters. Both may be of interest occasionally.\cr
  Singular covariance matrices during the iterations are handled by
  \code{\link{solvecov}}.

  \code{summary.mfpc} gives a summary about the representative FPCs of
  stable groups.

  \code{plot.mfpc} is a plot method for the representative FPC of stable
  group no. \code{no}. It produces a scatterplot, where
  the points belonging to the FPC are highlighted, the mean is and
  for \code{p<3} also the region of the FPC is shown. For \code{p>=3},
  the optimal separating projection computed by \code{\link{batcoord}}
  is shown.  

  \code{fpclusters.mfpc} produces a list of indicator vectors for the
  representative FPCs of stable groups.

  \code{fpmi} is called by \code{fixmahal} for a single fixed point
  algorithm and will usually not be executed alone.
}
\value{
  \code{fixmahal} returns an object of class \code{mfpc}. This is a list
  containing the components \code{nc, g, means, covs, nfound, er, tsc,
    ncoll, skc, grto, imatrix, smatrix, stn, stfound, ser, sfpc, ssig,
    sto, struc, n, p, method, cgen, ca, ca2, cvec, calpha, pointit,
    subset, mnc, startn, mer, distcut}.

  \code{summary.mfpc} returns an object of class \code{summary.mfpc}.
  This is a list containing the components \code{means, covs, stn,
    stfound, sn, ser, tskip, skc, tsc, sim, ca, ca2, calpha, mer, method,
    cgen, pointit}.

  \code{fpclusters.mfpc} returns a list of indicator vectors for the
  representative FPCs of stable groups.

  
  \code{fpmi} returns a list with the components \code{mg, covg, md,
    gv, coll, method, ca}.
  
  \item{nc}{integer. Number of FPCs.}
  \item{g}{list of logical vectors. Indicator vectors of FPCs. \code{FALSE}
    if \code{ind.storage=FALSE}.}
  \item{means}{list of numerical vectors. Means of FPCs. In
    \code{summary.mfpc}, only for representative
    FPCs of stable groups and sorted according to
    \code{ser}.}
  \item{covs}{list of numerical matrices. Covariance matrices of FPCs. In
    \code{summary.mfpc}, only for representative
    FPCs of stable groups and sorted according to
    \code{ser}.}
  \item{nfound}{vector of integers. Number of findings for the FPCs.}
  \item{er}{numerical vector. Ratio of number of findings of FPCs to their
    size. Under \code{pointit=TRUE},
    this can be taken as a measure of stability of FPCs.}
  \item{tsc}{integer. Number of algorithm runs leading to too small or
    too seldom found FPCs.}
  \item{ncoll}{integer. Number of algorithm runs where collinear
    covariance matrices occurred.}
  \item{skc}{integer. Number of skipped clusters.}
  \item{grto}{vector of integers. Numbers of FPCs to which algorithm
    runs led, which were started by \code{init.group}.}
  \item{imatrix}{vector of integers. Size of intersection between
    FPCs. See \code{\link{sseg}}.}
  \item{smatrix}{numerical vector. Similarities between
    FPCs. See \code{\link{sseg}}.}
  \item{stn}{integer. Number of representative FPCs of stable groups.
    In \code{summary.mfpc}, sorted according to \code{ser}.}
  \item{stfound}{vector of integers. Number of findings of members of
    all groups of FPCs. In \code{summary.mfpc}, sorted according to
    \code{ser}.}
  \item{ser}{numerical vector. Ratio of number of findings of groups of
    FPCs to their size. Under \code{pointit=TRUE},
    this can be taken as a measure of stability of FPCs. In
    \code{summary.mfpc}, sorted from largest to smallest.}
  \item{sfpc}{vector of integers.
    Numbers of representative FPCs of all groups.}
  \item{ssig}{vector of integers of length \code{stn}.
    Numbers of representative FPCs of the stable groups.}
  \item{sto}{vector of integers. Numbers of groups ordered
    according to largest \code{ser}.}
  \item{struc}{vector of integers. Number of group an FPC belongs to.}
  \item{n}{see arguments.}
  \item{p}{see arguments.}
  \item{method}{see arguments.}
  \item{cgen}{see arguments.}
  \item{ca}{see arguments, if \code{cgen} has been \code{"fixed"}. Else
    numerical vector of length \code{nc} (see below), giving the
    final values of \code{ca} for all FPC. In \code{fpmi}, tuning
    constant for the iterated FPC.}
  \item{ca2}{see arguments.}
  \item{cvec}{numerical vector of length \code{n} for
    \code{cgen="auto"}. The values for the
    tuning constant \code{ca} corresponding to the cluster sizes from
    \code{1} to \code{n}.}
  \item{calpha}{see arguments.}
  \item{pointit}{see arguments.}
  \item{subset}{see arguments.}
  \item{mnc}{see arguments.}
  \item{startn}{see arguments.}
  \item{mer}{see arguments.}
  \item{distcut}{see arguments.}

  \item{sn}{vector of integers. Number of points of representative
    FPCs.}
  \item{tskip}{integer. Number of algorithm runs leading to skipped FPCs.}
  \item{sim}{vector of integers. Size of intersections between
    representative FPCs of stable groups. See \code{\link{sseg}}.}

  \item{mg}{mean vector.}
  \item{covg}{covariance matrix.}
  \item{md}{Mahalanobis distances.}
  \item{gv}{logical (numerical, respectively, if \code{method="fuzzy"})
    indicator vector of iterated FPC.}
  \item{coll}{logical. \code{TRUE} means that singular covariance
    matrices occurred during the iterations.}
}
\references{
  Hennig, C. (2002) Fixed point clusters for linear regression:
  computation and comparison, \emph{Journal of
    Classification} 19, 249-276.

  Hennig, C. and Christlieb, N. (2002) Validating visual clusters in
  large datasets: Fixed point clusters of spectral features,
  \emph{Computational Statistics and Data Analysis} 40, 723-739.

}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}
\seealso{
\code{\link{fixreg}} for linear regression fixed point clusters.

\code{\link{mahalconf}}, \code{\link{wfu}}, \code{\link{cmahal}}
for computation of initial configurations, weights, tuning constants.  

\code{\link{sseg}} for indexing the similarity/intersection vectors
computed by \code{fixmahal}.

\code{\link{batcoord}}, \code{\link{cov.rob}}, \code{\link{solvecov}},
\code{\link{cov.wml}} for computation of projections, (inverted)
covariance matrices.

\code{\link{rFace}} for generation of example data, see below.
}
\examples{
  set.seed(20000)
  face <- rFace(400,dMoNo=2,dNoEy=0,p=3)
  ff1 <- fixmahal(face)
  # Executions of fixmahal may need some patience
  summary(ff1)
  cff1 <- fpclusters(ff1)
  plot(face, col=1+cff1[[1]])
  plot(face, col=1+cff1[[6]]) # Why does this come out as a cluster? 
  plot(ff1, face, 6) # A bit clearer...
  ff2 <- fixmahal(face,method="ml")
  summary(ff2)
  ff3 <- fixmahal(face,method="ml",calpha=0.95,subset=50)
  summary(ff3)
  # ...fast, but lots of clusters. mer=0.3 may be useful here.
  set.seed(3000)
  face2 <- rFace(400,dMoNo=2,dNoEy=0)
  ff5 <- fixmahal(face2)
  summary(ff5)
  # misses right eye of face data; with p=6,
  # initial configurations are too large for 40 point clusters 
  ff6 <- fixmahal(face2, startn=30)
  summary(ff6)
  cff6 <- fpclusters(ff6)
  plot(face2, col=1+cff6[[3]])
  plot(ff6, face2, 3)
  # ... or with use of prior information...
  initg <- list()
  grface <- as.integer(attr(face2,"grouping"))
  for (i in 1:5) initg[[i]] <- (grface==i)
  ff7 <- fixmahal(face2, pointit=FALSE, init.group=initg)
  summary(ff7)
  x <- c(1,2,3,6,6,7,8,120)
  ff8 <- fixmahal(x)
  summary(ff8)
  # ...dataset a bit too small for the defaults...
  ff9 <- fixmahal(x, mnc=3, startn=3)
  summary(ff9)
}
\keyword{cluster}% at least one, from doc/KEYWORDS
\keyword{multivariate}
\keyword{robust}% __ONLY ONE__ keyword per line


\eof
\name{fixreg}
\alias{fixreg}
\alias{summary.rfpc}
\alias{plot.rfpc}
\alias{fpclusters.rfpc}
\alias{print.summary.rfpc}
\alias{print.rfpc}
\alias{rfpi}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Linear Regression Fixed Point Clusters}
\description{
  Computes linear regression fixed point clusters (FPCs), i.e.,
  subsets of the data, which consist exactly of the
  non-outliers w.r.t. themselves, and may be interpreted
  as generated from a homogeneous linear regression relation
  between independent and dependent variable.  FPCs may
  overlap, are not necessarily exhausting and
  do not need a specification of the number of clusters.

  Note that while \code{fixreg} has lots of parameters, only one (or
  few) of them have usually to be specified, cf. the examples. The
  philosophy is to allow much flexibility, but to always provide 
  sensible defaults.
  
}
\usage{
fixreg(indep=rep(1,n), dep, n=length(dep),
                    p=ncol(as.matrix(indep)),
                    ca=NA, mnc=NA, mtf=3, ir=NA, irnc=NA,
                    irprob=0.95, mncprob=0.5, maxir=20000, maxit=5*n,
                    distcut=0.85, init.group=list(), 
                    ind.storage=FALSE, countmode=100, 
                    plot=FALSE)

\method{summary}{rfpc}(object, ...)

\method{plot}{rfpc}(x, indep=rep(1,n), dep, no, bw=TRUE,
                      main=c("Representative FPC No. ",no),
                      xlab="Linear combination of independents",
                      ylab=deparse(substitute(indep)),
                      xlim=NULL, ylim=range(dep), 
                      pch=NULL, col=NULL,...)

\method{fpclusters}{rfpc}(object, indep=NA, dep=NA, ca=object$ca, ...)

rfpi(indep, dep, p, gv, ca, maxit, plot) 
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{indep}{numerical matrix or vector. Independent
    variables.
    Leave out for clustering one-dimensional data.
    \code{fpclusters.rfpc}
    does not need specification of \code{indep} if \code{fixreg}
    was run with \code{ind.storage=TRUE}.}
  \item{dep}{numerical vector. Dependent variable.
    \code{fpclusters.rfpc}
    does not need specification of \code{dep} if \code{fixreg}
    was run with \code{ind.storage=TRUE}.}
  \item{n}{optional positive integer.
    Number of cases.}
  \item{p}{optional positive integer.
    Number of independent variables.}
  \item{ca}{optional positive number. Tuning constant, specifying
    required cluster
    separation. By default determined automatically as a
    function of \code{n} and \code{p}, see function \code{\link{can}},
    Hennig (2002a).}
  \item{mnc}{optional positive integer. Minimum size of clusters
    to be reported.
    By default determined automatically as a function of
    \code{mncprob}. See Hennig (2002a).}
  \item{mtf}{optional positive integer. FPCs must be found at
    least \code{mtf} times to be reported by \code{summary.rfpc}.}
  \item{ir}{optional positive integer. Number of algorithm runs.
    By default determined
    automatically as a function of \code{n}, \code{p}, \code{irnc},
    \code{irprob}, \code{mtf},
    \code{maxir}. See function \code{\link{itnumber}} and Hennig (2002a).}
  \item{irnc}{optional positive integer. Size of the smallest
    cluster to be found with
    approximated probability \code{irprob}.}
  \item{irprob}{optional value between 0 and 1. Approximated
    probability for a cluster of size \code{irnc} to be found.}
  \item{mncprob}{optional value between 0 amd 1. Approximated
    probability for a cluster of size \code{mnc} to be found.}
  \item{maxir}{optional integer. Maximum number of algorithm runs.}
  \item{maxit}{optional integer. Maximum number of iterations
    per algorithm run (usually an FPC is found much earlier).}
  \item{distcut}{optional value between 0 and 1. A similarity
    measure between FPCs, given in Hennig (2002a), and the corresponding
    Single Linkage groups of FPCs with similarity larger
    than \code{distcut} are computed.
    A single representative FPC is selected for each group.}
  \item{init.group}{optional list of logical vectors of length
    \code{n}.
    Every vector indicates a starting configuration for the fixed
    point algorithm. This can be used for datasets with high
    dimension, where the vectors of \code{init.group} indicate cluster
    candidates found by graphical inspection or background
    knowledge.}
  \item{ind.storage}{optional logical. If \code{TRUE},
    then all indicator
    vectors of found FPCs are given in the value of \code{fixreg}.
    May need lots of memory, but is a bit faster.}
  \item{countmode}{optional positive integer. Every \code{countmode}
    algorithm runs \code{fixreg} shows a message.}
  \item{plot}{optional logical. If \code{TRUE}, you get a scatterplot
    of first independent vs. dependent variable at each iteration.}
  \item{object}{object of class \code{rfpc}, output of \code{fixreg}.}
  \item{x}{object of class \code{rfpc}, output of \code{fixreg}.}
  \item{maxnc}{optional positive integer. Maximum number of FPCs
    to be reported.}
  \item{no}{positive integer. Number of the representative FPC to
    be plotted.}
  \item{bw}{optional logical. If \code{TRUE}, plot is black/white,
    FPC is
    indicated by different symbol. Else FPC is indicated red.}
  \item{main}{plot title.}
  \item{xlab}{label for x-axis.}
  \item{ylab}{label for y-axis.}
  \item{xlim}{plotted range of x-axis. If \code{NULL}, the range of the
    plotted linear combination of independent variables is used.}
  \item{ylim}{plotted range of y-axis.}
  \item{pch}{plotting symbol, see \code{\link{par}}.
    If \code{NULL}, the default is used.}
  \item{col}{plotting color, see \code{\link{par}}.
    If \code{NULL}, the default is used.}
  \item{gv}{logical vector of length \code{n}. Indicates the initial
    configuration for the fixed point algorithm.} 
  \item{...}{additional parameters to be passed to \code{plot}
    (no effects elsewhere).}
}
\details{A linear regression FPC is a data subset 
  that reproduces itself under the following operation: \cr
  Compute linear regression and error variance estimator for the data
  subset, and compute all points of the dataset for which the squared
  residual is smaller than \code{ca} times the error variance.\cr
  Fixed points of this operation can be considered as clusters,
  because they contain only
  non-outliers (as defined by the above mentioned procedure) and all other
  points are outliers w.r.t. the subset. \cr
  \code{fixreg} performs \code{ir} fixed point algorithms started from
  random subsets of size \code{p+2} to look for
  FPCs. Additionally an algorithm is started from the whole dataset,
  and algorithms are started from the subsets specified in
  \code{init.group}. \cr
  Usually some of the FPCs are unstable, and more than one FPC may
  correspond to the same significant pattern in the data. Therefore the
  number of FPCs is reduced: FPCs with less than \code{mnc} points are
  ignored. Then a similarity matrix is computed between the remaining
  FPCs. Similarity between sets is defined as the ratio between
  2 times size of
  intersection and the sum of sizes of both sets. The Single Linkage
  clusters (groups)
  of level \code{distcut} are computed, i.e. the connectivity
  components of the graph where edges are drawn between FPCs with
  similarity larger than \code{distcut}. Groups of FPCs whose members
  are found \code{mtf} times or more are considered as stable enough.
  A representative FPC is
  chosen for every Single Linkage cluster of FPCs according to the
  maximum expectation ratio \code{ser}. \code{ser} is the ratio between
  the number of findings of an FPC and the estimated
  expectation of the number of findings of an FPC of this size,
  called \emph{expectation ratio} and
  computed by \code{\link{clusexpect}}.\cr
  Usually only the representative FPCs of stable groups
  are of interest. \cr
  The choice of the involved tuning constants such as \code{ca} and
  \code{ir} is discussed in detail in Hennig (2002a). Statistical theory
  is presented in Hennig (2003).\cr
  Generally, the default settings are recommended for
  \code{fixreg}. In cases where they lead to a too large number of
  algorithm runs (e.g., always for \code{p>4}), the use of
  \code{init.group} together with \code{mtf=1} and \code{ir=0}
  is useful. Occasionally, \code{irnc} may be chosen
  smaller than the default,
  if smaller clusters are of interest, but this may lead to too many
  clusters and too many algorithm runs. Decrease of
  \code{ca} will often lead to too many clusters, even for homogeneous
  data. Increase of \code{ca} will produce only very strongly
  separated clusters. Both may be of interest occasionally.

  \code{rfpi} is called by \code{fixreg} for a single fixed point
  algorithm and will usually not be executed alone.

  \code{summary.rfpc} gives a summary about the representative FPCs of
  stable groups.

  \code{plot.rfpc} is a plot method for the representative FPC of stable
  group 
  no. \code{no}. It produces a scatterplot of the linear combination of
  independent variables determined by the regression coefficients of the
  FPC vs. the dependent variable. The regression line and the region
  of non-outliers determined by \code{ca} are plotted as well.

  \code{fpclusters.rfpc} produces a list of indicator vectors for the
  representative FPCs of stable groups.
}
\value{
  \code{fixreg} returns an object of class \code{rfpc}. This is a list
  containing the components \code{nc, g, coefs, vars, nfound, er, tsc,
    ncoll, grto, imatrix, smatrix, stn, stfound, sfpc, ssig, sto, struc,
    n, p, ca, ir, mnc, mtf, distcut}.

  \code{summary.rfpc} returns an object of class \code{summary.rfpc}.
  This is a list containing the components \code{coefs, vars, stfound,
    stn, sn, ser, tsc, sim, ca, ir, mnc, mtf}.

  \code{fpclusters.rfpc} returns a list of indicator vectors for the
  representative FPCs of stable groups.

  \code{rfpi} returns a list with the components \code{coef, var, g,
    coll, ca}.
  
  \item{nc}{integer. Number of FPCs.}
  \item{g}{list of logical vectors. Indicator vectors of FPCs. \code{FALSE}
    if \code{ind.storage=FALSE}.}
  \item{coefs}{list of numerical vectors. Regression coefficients of
    FPCs. In \code{summary.rfpc}, only for representative
    FPCs of stable groups and sorted according to
    \code{stfound}.}
  \item{vars}{list of numbers. Error variances of FPCs. In
    \code{summary.rfpc}, only for representative
    FPCs of stable groups and sorted according to
    \code{stfound}.}
  \item{nfound}{vector of integers. Number of findings for the FPCs.}
  \item{er}{numerical vector. Expectation ratios of FPCs. Can be
    taken as a stability measure.}
  \item{tsc}{integer. Number of algorithm runs leading to too small or
    too seldom found FPCs.}
  \item{ncoll}{integer. Number of algorithm runs where collinear
    regressor matrices occurred.}
  \item{grto}{vector of integers. Numbers of FPCs to which algorithm
    runs led, which were started by \code{init.group}.}
  \item{imatrix}{vector of integers. Size of intersection between
    FPCs. See \code{\link{sseg}}.}
  \item{smatrix}{numerical vector. Similarities between
    FPCs. See \code{\link{sseg}}.}
  \item{stn}{integer. Number of representative FPCs of stable groups. In
    \code{summary.rfpc} sorted according to \code{stfound}.}
  \item{stfound}{vector of integers. Number of findings of members of
    all groups of FPCs. In
    \code{summary.rfpc} sorted according to \code{stfound}.}
  \item{sfpc}{vector of integers. Numbers of representative FPCs.}
  \item{ssig}{vector of integers. As \code{sfpc}, but only for stable
    groups.}
  \item{sto}{vector of integers. Number of representative FPC of most,
    2nd most, ..., often found group of FPCs.}
  \item{struc}{vector of integers. Number of group an FPC belongs to.}
  \item{n}{see arguments.}
  \item{p}{see arguments.}
  \item{ca}{see arguments.}
  \item{ir}{see arguments.}
  \item{mnc}{see arguments.}
  \item{mtf}{see arguments.}
  \item{distcut}{see arguments.}

  \item{sn}{vector of integers. Number of points of representative
    FPCs.}
  \item{ser}{numerical vector. Expectation ratio for stable groups.}
  \item{sim}{vector of integers. Size of intersections between
    representative FPCs of stable groups. See \code{\link{sseg}}.}

  \item{coef}{vector of regression coefficients.}
  \item{var}{error variance.}
  \item{g}{logical indicator vector of iterated FPC.}
  \item{coll}{logical. \code{TRUE} means that singular covariance
    matrices occurred during the iterations.}
}
\references{
  Hennig, C. (2002) Fixed point clusters for linear regression:
  computation and comparison, \emph{Journal of
    Classification} 19, 249-276.

  Hennig, C. (2003) Clusters, outliers and regression:
  fixed point clusters, \emph{Journal of
    Multivariate Analysis} 86, 183-212.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}
\seealso{
\code{\link{fixmahal}} for fixed point clusters in the usual setup
(non-regression).

\code{\link{regmix}} for clusterwiese linear regression by mixture
modeling ML.

\code{\link{can}}, \code{\link{itnumber}} for computation of the default
settings.  

\code{\link{clusexpect}} for estimation of the expected number of
findings of an FPC of given size.

\code{\link{itnumber}} for the generation of the number of fixed point
algorithms.

\code{\link{minsize}} for the smallest FPC size to be found with a given
probability..

\code{\link{sseg}} for indexing the similarity/intersection vectors
computed by \code{fixreg}.
}
\examples{
set.seed(1000)
data(tonedata)
# Note: If you do not use the installed package, replace this by
# tonedata <- read.table("(path/)tonedata.txt", header=TRUE)
attach(tonedata)
tonefix <- fixreg(stretchratio,tuned)
# Default - good for these data
summary(tonefix)
plot(tonefix,stretchratio,tuned,1)
plot(tonefix,stretchratio,tuned,2)
plot(tonefix,stretchratio,tuned,3,bw=FALSE,pch=5) 
toneclus <- fpclusters(tonefix,stretchratio,tuned)
plot(stretchratio,tuned,col=1+toneclus[[2]])
tonefix2 <- fixreg(stretchratio,tuned,distcut=1,mtf=1,countmode=50)
# Every found fixed point cluster is reported,
# no matter how instable it may be.
summary(tonefix2)
tonefix3 <- fixreg(stretchratio,tuned,ca=7)
# ca defaults to 10.07 for these data.
summary(tonefix3)
subset <- c(rep(FALSE,5),rep(TRUE,24),rep(FALSE,121))
tonefix4 <- fixreg(stretchratio,tuned,
                   mtf=1,ir=0,init.group=list(subset))
summary(tonefix4)
}
\keyword{cluster}% at least one, from doc/KEYWORDS
\keyword{robust}% __ONLY ONE__ keyword per line
\keyword{regression}

\eof
\name{fpclusters}
\alias{fpclusters}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Extracting clusters from fixed point cluster objects}
\description{
  \code{fpclusters} is a generic function which extracts the
  representative fixed point clusters (FPCs)
  from FPC objects generated by \code{\link{fixmahal}} and
  \code{\link{fixreg}}. For documentation and examples see
  \code{\link{fixmahal}} and  \code{\link{fixreg}}.
}
\usage{
fpclusters(object, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{object}{object of class \code{rfpc} or \code{mfpc}.}
  \item{...}{further arguments depending on the method.}
}

\value{
  a list of logical or numerical vectors indicating or giving the
  weights of the cluster memberships.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{\code{\link{fixmahal}}, \code{\link{fixreg}}}

\keyword{cluster}% at least one, from doc/KEYWORDS

\eof
\name{itnumber}
\alias{itnumber}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Number of regression fixed point cluster iterations}
\description{
  Computes the number of fixed point iterations needed by
  \code{\link{fixreg}} to find \code{mtf} times
  a fixed point cluster (FPC) of size
  \code{cn} with an approximated probability of \code{prob}.

  Thought for use within \code{\link{fixreg}}.
}
\usage{
itnumber(n, p, cn, mtf, prob = 0.95, maxir = 20000)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{positive integer. Total number of points.}
  \item{p}{positive integer. Number of independent variables.}
  \item{cn}{positive integer smaller or equal to \code{n}.
    Size of the FPC.}
  \item{mtf}{positive integer.}
  \item{prob}{number between 0 and 1.}
  \item{maxir}{positive integer. \code{itnumber} is set to this value if
    it would otherwise be larger.}
}
\details{
  The computation is based on the binomial distribution with probability
  given by \code{\link{clusexpect}} with \code{ir=1}.
}
\value{
  An integer.
}
\references{
  Hennig, C. (2002) Fixed point clusters for linear regression:
  computation and comparison, \emph{Journal of
    Classification} 19, 249-276.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{fixreg}}, \code{\link{clusexpect}}}

\examples{
  itnumber(500,4,150,2)
}
\keyword{univar}% at least one, from doc/KEYWORDS
\keyword{cluster}% __ONLY ONE__ keyword per line
\eof
\name{mahalanodisc}
\alias{mahalanodisc}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Mahalanobis for AWC}
\description{
  Vector of Mahalanobis distances or their root. For use in \code{awcoord} only.
}
\usage{
mahalanodisc(x2, mg, covg, modus="square") 

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x2}{numerical data matrix.}
  \item{mg}{mean vector.}
  \item{covg}{covariance matrix.}
  \item{modus}{"md" (roots of Mahalanobis distances) or "square"
    (original squared form of Mahalanobis distances).}
}
\details{
  The covariance matrix
  is inverted by use of
  \code{\link{solvecov}}, which can be expected to give
  reasonable results for singular within-class covariance matrices.
}
% \details{
% }
\value{
  vector of (rooted) Mahalanobis distances.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{awcoord}}, \code{\link{solvecov}}
}

\examples{
  x <- cbind(rnorm(50),rnorm(50))
  mahalanodisc(x,c(0,0),cov(x))
  mahalanodisc(x,c(0,0),matrix(0,ncol=2,nrow=2))
}
\keyword{multivariate}% at least one, from doc/KEYWORDS



\eof
\name{mahalanofix}
\alias{mahalanofix}
\alias{mahalanofuz}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Mahalanobis distances from center of indexed points}
\description{
  Computes the vector of (classical or robust)
  Mahalanobis distances of all points of \code{x}
  to the center of the points indexed (or weighted)
  by \code{gv}. The latter also determine
  the covariance matrix.

  Thought for use within \code{\link{fixmahal}}.
}
\usage{
mahalanofix(x, n = nrow(as.matrix(x)), p = ncol(as.matrix(x)), gv =
rep(1, times = n), cmax = 1e+10, method = "ml")

mahalanofuz(x, n = nrow(as.matrix(x)), p = ncol(as.matrix(x)),
                         gv = rep(1, times=n), cmax = 1e+10) 
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{a numerical data matrix, rows are points, columns are variables.}
  \item{n}{positive integer. Number of points.}
  \item{p}{positive integer. Number of variables.}
  \item{gv}{for \code{mahalanofix}
    a logical or 0-1 vector of length \code{n}. For \code{mahalanofuz} a
    numerical vector with values between 0 and 1.}
  \item{cmax}{positive number. used in \code{\link{solvecov}} if
    covariance matrix is singular.}
  \item{method}{\code{"ml"}, \code{"classical"},
    \code{"mcd"} or \code{"mve"}. Method to compute the covariance
    matrix estimator. See \code{\link{cov.rob}}, \code{\link{fixmahal}}.}
  
}
\details{
  \code{\link{solvecov}} is used to invert the covariance matrix. The methods
  \code{"mcd"} and \code{"mve"} in \code{mahalanofix} do not work properly
  with point constellations with singular covariance matrices!
}
\value{
  A list of the following components:
  \item{md}{vector of Mahalanobis distances.}
  \item{mg}{mean of the points indexed by \code{gv}, weighted mean in
    \code{mahalanofuz}.}
  \item{covg}{covariance matrix of the points indexed by \code{gv},
    weighted covariance matrix in \code{mahalanofuz}.} 
  \item{covinv}{\code{covg} inverted by \code{\link{solvecov}}.}
  \item{coll}{logical. If \code{TRUE}, \code{covg} has been
    (numerically) singular.}
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\note{Methods \code{"mcd"} and \code{"mve"} require library \code{lqs}.}

\seealso{\code{\link{fixmahal}}, \code{\link{solvecov}}, \code{\link{cov.rob}}}

\examples{
  x <- c(1,2,3,4,5,6,7,8,9,10)
  y <- c(1,2,3,8,7,6,5,8,9,10)
  mahalanofix(cbind(x,y),gv=c(0,0,0,1,1,1,1,1,0,0))
  mahalanofix(cbind(x,y),gv=c(0,0,0,1,1,1,1,0,0,0))
  mahalanofix(cbind(x,y),gv=c(0,0,0,1,1,1,1,1,0,0),method="mcd")
  mahalanofuz(cbind(x,y),gv=c(0,0,0.5,0.5,1,1,1,0.5,0.5,0))
}
\keyword{multivariate}% at least one, from doc/KEYWORDS





\eof
\name{mahalconf}
\alias{mahalconf}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Mahalanobis fixed point clusters initial configuration}
\description{
  Generates an initial configuration of \code{startn} points from
  dataset \code{x} for the \code{\link{fixmahal}}
  fixed point iteration.

  Thought only for use within \code{\link{fixmahal}}.
}
\usage{
mahalconf(x, no, startn, covall, plot)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{numerical matrix. Rows are points, columns are variables.}
  \item{no}{integer between 1 and \code{nrow(x)}. Number of the first
    point of the configuration.}
  \item{startn}{integer between 1 and \code{nrow(x)}.}
  \item{covall}{covariance matrix for the computation of the first
    Mahalanobis distances.}
  \item{plot}{a string. If equal to \code{"start"} or \code{"both"},the
    first two variables and the first \code{ncol(x)+1} points are plotted.}
}
\details{
  \code{mahalconf} first chooses the \eqn{p} (number of variables)
  nearest points to point no. \code{no} in terms of the Mahalanobis
  distance w.r.t. \code{covall}, so that there are \eqn{p+1} points.
  In every further step, the covariance
  matrix of the current configuration is computed and the nearest point
  in terms of the new Mahalanobis distance is
  added. \code{\link{solvecov}} is used to invert singular covariance
  matrices. 
}
\value{
  A logical vector of length \code{nrow(x)}.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{fixmahal}}, \code{\link{solvecov}}}

\examples{
  set.seed(4634)
  face <- rFace(600,dMoNo=2,dNoEy=0,p=2)
  mahalconf(face,no=200,startn=20,covall=cov(face),plot="start")
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{cluster}
\eof
\name{minsize}
\alias{minsize}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Minimum size of regression fixed point cluster}
\description{
  Computes the minimum size of a fixed point cluster (FPC) which is
  found at least \code{mtf} times with approximated
  probability \code{prob} by
  \code{ir} fixed point iterations of \code{\link{fixreg}}.

  Thought for use within \code{\link{fixreg}}.
}
\usage{
minsize(n, p, ir, mtf, prob = 0.5)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{positive integer. Total number of points.}
  \item{p}{positive integer. Number of independent variables.}
  \item{ir}{positive integer. Number of fixed point iterations.}
  \item{mtf}{positive integer.}
  \item{prob}{numerical between 0 and 1.}
}
\details{
  The computation is based on the binomial distribution with probability
  given by \code{\link{clusexpect}} with \code{ir=1}.
}
\value{
  An integer.
}
\references{
  Hennig, C. (2002) Fixed point clusters for linear regression:
  computation and comparison, \emph{Journal of
    Classification} 19, 249-276.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{fixreg}}, \code{\link{clusexpect}},
  \code{\link{itnumber}}}

\examples{
  minsize(500,4,7000,2)
}
\keyword{univar}% at least one, from doc/KEYWORDS
\keyword{cluster}% __ONLY ONE__ keyword per line
\eof
\name{mvdcoord}
\alias{mvdcoord}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Mean/variance differences discriminant coordinates}
\description{
  Discriminant projections as defined in Young, Marco and Odell (1987).
  The principle is to maximize the projection of a matrix consisting of
  the differences between the means of all classes and the first mean
  and the differences between the covariance matrices of all classes and
  the forst covariance matrix.
}
\usage{
mvdcoord(xd, clvecd, clnum=1, sphere="mcd", ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{xd}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{integer vector of class numbers; length must equal
    \code{nrow(xd)}.}
  \item{clnum}{integer. Number of the class to which all differences are
    computed.}
  \item{sphere}{a covariance matrix or one of
    "mve", "mcd", "classical", "none". The matrix used for sphering the
    data. "mcd" and "mve" are robust covariance matrices as implemented
    in \code{\link{cov.rob}}. "classical" refers to the classical
    covariance matrix. "none" means no sphering and use of the raw
    data.}
  \item{...}{no effect}
}
% \details{
% }
\value{
  List with the following components
  \item{ev}{eigenvalues in descending order.}
  \item{units}{columns are coordinates of projection basis vectors.
  New points \code{x} can be projected onto the projection basis vectors
  by \code{x \%*\% units}}
  \item{proj}{projections of \code{xd} onto \code{units}.} 
}
\references{
  Young, D. M., Marco, V. R. and Odell, P. L. (1987). Quadratic
  discrimination: some results on optimal low-dimensional
  representation, \emph{Journal of Statistical Planning and Inference},
  17, 307-319.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{plotcluster}} for straight forward discriminant plots.
  \code{\link{discrproj}} for alternatives.
  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
  set.seed(4634)
  face <- rFace(600,dMoNo=2,dNoEy=0)
  grface <- as.integer(attr(face,"grouping"))
  mcf <- mvdcoord(face,grface)
  plot(mcf$proj,col=grface)
  # ...done in one step by function plotcluster.
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line



\eof
\name{ncoord}
\alias{ncoord}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Neighborhood based discriminant coordinates}
\description{
  Neighborhood based discriminant coordinates as defined in Hastie and
  Tibshirani (1996) and a robustified version as defined in Hennig (2003).
  The principle is to maximize the projection of a between
  classes covariance matrix, which is defined by averaging the
  between classes covariance matrices in the neighborhoods of all points.  
}
\usage{
ncoord(xd, clvecd, nn=50, weighted=FALSE,
                    sphere="mcd", orderall=TRUE, countmode=1000, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{xd}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{integer vector of class numbers; length must equal
    \code{nrow(xd)}.}
  \item{nn}{integer. Number of points which belong to the neighborhood
    of each point (including the point itself).}
  \item{weighted}{logical. \code{FALSE} corresponds to the original
    method of Hastie and Tibshirani (1996). If \code{TRUE},
    the between classes
    covariance matrices B are weighted by w/trace B, where w is some
    weight depending on the sizes of the
    classes in the neighborhood. Division by trace B reduces the effect
    of outliers. \code{TRUE} cooresponds to WNC as defined in Hennig
    (2003).}
  \item{sphere}{a covariance matrix or one of
    "mve", "mcd", "classical", "none". The matrix used for sphering the
    data. "mcd" and "mve" are robust covariance matrices as implemented
    in \code{\link{cov.rob}}. "classical" refers to the classical
    covariance matrix. "none" means no sphering and use of the raw
    data.}
  \item{orderall}{logical. By default, the neighborhoods are computed by
    ordering all points each time. If \code{FALSE}, the neighborhoods
    are computed by selecting \code{nn} times the nearest point from the
    remaining points, which may be faster sometimes.}
  \item{countmode}{optional positive integer. Every \code{countmode}
    algorithm runs \code{ncoord} shows a message.}
  \item{...}{no effect}
}
% \details{
% }
\value{
  List with the following components
  \item{ev}{eigenvalues in descending order.}
  \item{units}{columns are coordinates of projection basis vectors.
  New points \code{x} can be projected onto the projection basis vectors
  by \code{x \%*\% units}}
  \item{proj}{projections of \code{xd} onto \code{units}.} 
}
\references{
  Hastie, T. and Tibshirani, R.  (1996). Discriminant adaptive nearest
  neighbor classification. \emph{IEEE Transactions on Pattern Analysis
  and Machine Intelligence} 18, 607-616. 

  Hennig, C. (2003) Symmetric, asymmetric, and robust linear dimension
  reduction for classification, submitted,
  \url{http://stat.ethz.ch/Research-Reports/108.html}.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}

\seealso{
  \code{\link{plotcluster}} for straight forward discriminant plots.
  \code{\link{discrproj}} for alternatives.
  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
  set.seed(4634)
  face <- rFace(600,dMoNo=2,dNoEy=0)
  grface <- as.integer(attr(face,"grouping"))
  ncf <- ncoord(face,grface)
  plot(ncf$proj,col=grface)
  ncf2 <- ncoord(face,grface,weighted=TRUE)
  plot(ncf2$proj,col=grface)
  # ...done in one step by function plotcluster.
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line



\eof
\name{plotcluster}
\alias{plotcluster}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Discriminant projection plot.}
\description{
  Plots to distinguish given classes by ten available projection
  methods. Includes classical discriminant
  coordinates, methods to project differences in
  mean and covariance structure, asymmetric methods (separation of a
  homogeneous class from a heterogeneous one), local neighborhood-based
  methods and methods based on robust covariance matrices.
}
\usage{
plotcluster(x, clvecd, clnum=1,
            method=ifelse(identical(range(as.integer(clvecd)),
                          as.integer(c(0,1))),"awc","dc"),
            bw=FALSE, xlab=NULL, ylab=NULL,
            pch=NULL, col=NULL, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{the data matrix; a numerical object which can be coerced
    to a matrix.}
  \item{clvecd}{vector of class numbers which can be coerced into
    integers; length must equal
    \code{nrow(xd)}.}
  \item{method}{one of
    \describe{
      \item{"dc"}{usual discriminant coordinates, see \code{\link{discrcoord}},}
      \item{"bc"}{Bhattacharyya coordinates, first coordinate showing
	mean differences, second showing covariance matrix differences,
	see \code{\link{batcoord}},}
      \item{"vbc"}{variance dominated Bhattacharyya coordinates,
	see \code{\link{batcoord}},}
      \item{"mvdc"}{added meana and variance differences optimizing
	coordinates, see \code{\link{mvdcoord}},}
      \item{"adc"}{asymmetric discriminant coordinates, see
	\code{\link{adcoord}},}
      \item{"awc"}{asymmetric discriminant coordinates with weighted
	observations, see \code{\link{awcoord}},}
      \item{"arc"}{asymmetric discriminant coordinates with weighted
	observations and robust MCD-covariance matrix,
	see \code{\link{awcoord}},}
      \item{"nc"}{neighborhood based coordinates,
	see \code{\link{ncoord}},}
      \item{"wnc"}{neighborhood based coordinates with weighted neighborhoods,
	see \code{\link{ncoord}},}
      \item{"anc"}{asymmetric neighborhood based coordinates,
	see \code{\link{ancoord}}.}
    }
    Note that "bc", "vbc", "adc", "awc", "arc" and "anc" assume that
    there are only two classes.}
  \item{clnum}{integer. Number of the class which is attempted to plot
    homogeneously by "asymmetric methods", which are the methods
    assuming that there are only two classes, as indicated above.} 
  \item{bw}{logical. If \code{TRUE}, the classes are distinguished by
    symbols, and the default color is black/white.
    If \code{FALSE}, the classes are distinguished by
    colors, and the default symbol is \code{pch=1}.}
  \item{xlab}{label for x-axis. If \code{NULL}, a default text is used.}
  \item{ylab}{label for y-axis. If \code{NULL}, a default text is used.}
  \item{pch}{plotting symbol, see \code{\link{par}}.
    If \code{NULL}, the default is used.}
  \item{col}{plotting color, see \code{\link{par}}.
    If \code{NULL}, the default is used.}
  \item{...}{additional parameters passed to \code{plot} or the
    projection methods.}
}
% \details{

% }

\references{
  Hennig, C. (2003) Symmetric, asymmetric, and robust linear dimension
  reduction for classification, submitted,
  \url{http://stat.ethz.ch/Research-Reports/108.html}.
  
  Seber, G. A. F. (1984). \emph{Multivariate Observations}. New York: Wiley.

  Fukunaga (1990). \emph{Introduction to Statistical Pattern
  Recognition} (2nd ed.). Boston: Academic Press.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{
  \code{\link{discrcoord}}, \code{\link{batcoord}},
  \code{\link{mvdcoord}}, \code{\link{adcoord}},
  \code{\link{awcoord}}, \code{\link{ncoord}},
  \code{\link{ancoord}}.

  \code{\link{discrproj}} is an interface to all these projection methods.

  \code{\link{rFace}} for generation of the example data used below.
}

\examples{
set.seed(4634)
face <- rFace(600,dMoNo=2,dNoEy=0)
grface <- as.integer(attr(face,"grouping"))
plotcluster(face,grface)
plotcluster(face,grface==1)
}
\keyword{multivariate}% at least one, from doc/KEYWORDS
\keyword{classif}% __ONLY ONE__ keyword per line



\eof
\name{rFace}
\alias{rFace}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{"Face-shaped" clustered benchmark datasets}
\description{
  Generates "face-shaped" clustered benchmark datasets.
}
\usage{
rFace(n, p = 6, nrep.top = 2, smile.coef = 0.6, dMoNo = 1.2, dNoEy = 1)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{integer greater or equal to 10. Number of points.}
  \item{p}{integer greater or equal to 2. Dimension.}
  \item{nrep.top}{integer. Number of repetitions of the hair-top point.}
  \item{smile.coef}{numeric. Coefficient for quadratic term used for
    generation of mouth-points. Positive values=>smile.}
  \item{dMoNo}{number. Distance from mouth to nose.}
  \item{dNoEy}{number. Minimum vertical distance from mouth to eyes.}
}
\details{
  The function generates a nice benchmark example for cluster
  analysis. 
  There are six "clusters" in this data, of which the first five are
  clearly homogeneous patterns, but with different distributional
  shapes and different qualities of separation. The clusters are
  distinguished only in the first two dimensions. The attribute
  \code{grouping} is a factor giving the cluster numbers, see below.
  The sixth group of
  points corresponds to some hairs, and is rather a collection of
  outliers than a cluster in itself. This group contains
  \code{nrep.top+2} points. Of the remaining points, 20\% belong to
  cluster 1, the chin (quadratic function plus noise).
  10\% belong to cluster 2, the right eye (Gaussian). 30\% belong to
  cluster 3, the mouth (Gaussian/squared Gaussian). 
  20\% belong to cluster 4, the nose (Gaussian/gamma), and
  20\% belong to cluster 5, the left eye (uniform).

  The distributions of the further
  variables are homogeneous over
  all points. The third dimension is exponentially distributed, the
  fourth dimension is Cauchy distributed, all further distributions are
  Gaussian.
  
  Please consider the source code for exact generation of the clusters.
}
\value{
  An \code{n} times \code{p} numeric matrix with attributes
  \item{grouping}{a factor giving the cluster memberships of the points.}
  \item{indexlist}{a list of six vectors containing the indices of points
    belonging to the six groups.}
}

\author{Martin Maechler
  \email{maechler@stat.math.ethz.ch}
  \url{http://stat.ethz.ch/~maechler/}
  
  Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\examples{
  set.seed(4634)
  face <- rFace(600,dMoNo=2,dNoEy=0)
  grface <- as.integer(attr(face,"grouping"))
  plot(face, col = grface)
  pairs(face, col = grface, main ="rFace(600,dMoNo=2,dNoEy=0)")
}
\keyword{data}% at least one, from doc/KEYWORDS
\eof
\name{randcmatrix}
\alias{randcmatrix}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Random partition matrix}
\description{
  For use within \code{regmix}. Generates a random
  0-1-matrix with \code{n} rows
  and \code{cln} columns so that every row contains exactly one one and
  every columns contains at least \code{p+3} ones.
}
\usage{
randcmatrix(n,cln,p)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{positive integer. Number of rows.}
  \item{cln}{positive integer. Number of columns.}
  \item{p}{positive integer. See above.}
}
\value{
  An \code{n*cln}-matrix.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}
\seealso{
  \code{\link{regmix}}
}
\examples{
set.seed(111)
randcmatrix(10,2,1)
}
\keyword{cluster}% at least one, from doc/KEYWORDS

\eof
\name{randconf}
\alias{randconf}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Generate a sample indicator vector}
\description{
  Generates a logical vector of length \code{n} with \code{p TRUE}s.
}
\usage{
randconf(n, p)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{n}{positive integer.}
  \item{p}{positive integer.}
}

\value{
  A logical vector.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{sample}}}

\examples{
  randconf(10,3)
}
\keyword{distribution}% at least one, from doc/KEYWORDS

\eof
\name{regmix}
\alias{regmix}
\alias{regem}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Mixture Model ML for Clusterwise Linear Regression}
\description{
  Computes an ML-estimator for clusterwise linear regression under a
  regression mixture model with Normal errors. Parameters are
  proportions, regression coefficients and error variances, all
  independent of the values of the independent variable, and all may
  differ for different clusters. Computation is by the EM-algorithm. The
  number of clusters is estimated via the Bayesian Information Criterion
  (BIC).
}
\usage{
regmix(indep, dep, ir=1, nclust=1:7, icrit=1.e-5, minsig=1.e-6, warnings=FALSE)

regem(indep, dep, m, cln, icrit=1.e-5, minsig=1.e-6, warnings=FALSE) 

}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{indep}{numerical matrix or vector. Independent
    variables.}
  \item{dep}{numerical vector. Dependent variable.}
  \item{ir}{positive integer.
    Number of iteration runs for every number of clusters.}
  \item{nclust}{vector of positive integers.
    Numbers of clusters.}
  \item{icrit}{positive numerical. Stopping criterion for the iterations
    (difference of loglikelihoods).}
  \item{minsig}{positive numerical. Minimum value for the variance
    parameters (likelihood is unbounded if variances are allowed to
    converge to 0).}
  \item{warnings}{logical. If \code{TRUE}, warnings are given during the
    EM iteration in case of collinear regressors, too small mixture
    components and error variances
    smaller than minimum. In the former two cases, the algorithm is
    terminated without a result, but an optimal solution is still
    computed from other algorithm runs (if there are others). In the
    latter case, the corresponding variance is set to the minimum.}
  \item{cln}{positive integer. (Single) number of clusters.}
  \item{m}{matrix of positive numericals. Number of columns must be
    \code{cln}. Number of rows must be number of data points. Columns
    must add up to 1. Initial configuration for the EM iteration in
    terms of a probabilty vector for every point which gives its degree
    of membership to every cluster. As generated by \code{\link{randcmatrix}}.}
}
\details{
  The result of the EM iteration depends on the initial configuration,
  which is generated randomly by \code{\link{randcmatrix}} for \code{regmix}.
  \code{regmix} calls \code{regem}. To provide the initial configuration
  manually, use parameter \code{m} of
  \code{regem} directly. Take a look at the example about how to
  generate \code{m} if you want to specify initial parameters.

  The original paper DeSarbo and Cron (1988) suggests the AIC for
  estimating the number of clusters. The use of the BIC is advocated by
  Wedel and DeSarbo (1995). The BIC is defined here as
  \code{2*loglik - log(n)*((p+3)*cln-1)}, \code{p} being the number of
  independent variables, i.e., the larger the better.

  See the entry for the input parameter \code{warnings} for the
  treatment of several numerical problems.
}
\value{
  \code{regmix} returns a list
  containing the components \code{clnopt, loglik, bic,
    coef, var, eps, z, g}.

  \code{regem}  returns a list
  containing the components \code{loglik, 
    coef, var, z, g, warn}.
  
  \item{clnopt}{optimal number of clusters according to the BIC.}
  \item{loglik}{loglikelihood for the optimal model.}
  \item{bic}{vector of BIC values for all numbers of clusters in \code{nclust}.}
  \item{coef}{matrix of regression coefficients. First row: intercept
    parameter. Second row: parameter of first independent variable and
    so on. Columns corresponding to clusters.}
  \item{var}{vector of error variance estimators for the clusters.}
  \item{eps}{vector of cluster proportion estimators.}
  \item{z}{matrix of estimated a posteriori probabilities of the points
    (rows) to be generated by the clusters (columns). Compare input
    argument \code{m}.}
  \item{g}{integer vector of estimated cluster numbers for the points
    (via argmax over \code{z}).}
  \item{warn}{logical. \code{TRUE} if one of the estimated clusters has
    too few points and/or collinear regressors.} 
}
\references{
  DeSarbo, W. S. and Cron, W. L. (1988) A maximum likelihood methodology
  for clusterwise linear regression, \emph{Journal of
    Classification} 5, 249-282.

  Wedel, M. and DeSarbo, W. S. (1995) A mixture likelihood approach for
  generalized linear models, \emph{Journal of
    Classification} 12, 21-56.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}
\seealso{
\code{\link{fixreg}} for fixed point clusters for clusterwise linear regression.

\code{\link[mclust]{EMclust}} for Normal mixture model fitting (non-regression).
}
\examples{
set.seed(12234)
data(tonedata)
# Note: If you do not use the installed package, replace this by
# tonedata <- read.table("(path/)tonedata.txt", header=TRUE)
attach(tonedata)
rmt1 <- regmix(stretchratio,tuned)
rmt1$g
rmt1$bic
# start with initial parameter values
cln <- 3
n <- 150
initcoef <- cbind(c(2,0),c(0,1),c(0,2.5))
initvar <- c(0.001,0.0001,0.5)
initeps <- c(0.4,0.3,0.3)
# computation of m from initial parameters
m <- matrix(nrow=n, ncol=cln)
stm <- numeric(0)
for (i in 1:cln)
  for (j in 1:n){
    m[j,i] <- initeps[i]*dnorm(tuned[j],mean=initcoef[1,i]+
              initcoef[2,i]*stretchratio[j], sd=sqrt(initvar[i]))
  }
  for (j in 1:n){
    stm[j] <- sum(m[j,])
    for (i in 1:cln)
      m[j,i] <- m[j,i]/stm[j]
  } 
rmt2 <- regem(stretchratio, tuned, m, cln)
rmt2bic <- 2*rmt2$loglik - log(150)*(4*cln-1)
rmt2bic
}
\keyword{cluster}% at least one, from doc/KEYWORDS
\keyword{regression}

\eof
\name{simmatrix}
\alias{simmatrix}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Extracting intersections between clusters from fpc-object}
\description{
  Extracts the information about the size of the intersections
  between representative
  Fixed Point Clusters (FPCs) of stable groups from the output of
  the FPC-functions \code{\link{fixreg}} and \code{\link{fixmahal}}.
}
\usage{
simmatrix(fpcobj)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{fpcobj}{an object of class \code{rfpc} or \code{mfpc}.}
}

\value{
  A non-negative real-valued vector giving the number of points in
  the intersections of the representative FPCs of stable groups.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}
\note{The intersection between representative FPCs no. \code{i} and
  \code{j} is at position \code{\link{sseg}(i,j)}.}

\seealso{
  \code{\link{fixmahal}},
  \code{\link{fixreg}},
  \code{\link{sseg}}
}

\examples{
set.seed(1000)
data(tonedata)
# Note: If you do not use the installed package, replace this by
# tonedata <- read.table("(path/)tonedata.txt", header=TRUE)
attach(tonedata)
tonefix <- fixreg(stretchratio,tuned)
simmatrix(tonefix)[sseg(2,3)]
}
\keyword{utilities}% at least one, from doc/KEYWORDS

\eof
\name{solvecov}
\alias{solvecov}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Inversion of (possibly singular) symmetric matrices}
\description{
  Tries to invert a matrix by \code{solve}. If this fails because of
  singularity, an
  eigenvector decomposition is computed, and eigenvalues below
  \code{1/cmax} are replaced by \code{1/cmax}, i.e., \code{cmax} will be
  the corresponding eigenvalue of the inverted matrix.
}
\usage{
solvecov(m, cmax = 1e+10)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{m}{a numeric symmetric matrix.}
  \item{cmax}{a positive value, see above.}
}

\value{
  A list with the following components:
  \item{inv}{the inverted matrix}
  \item{coll}{\code{TRUE} if \code{solve} failed because of singularity.}
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{solve}}, \code{\link{La.eigen}}}

\examples{
  x <- c(1,0,0,1,0,1,0,0,1)
  dim(x) <- c(3,3)
  solvecov(x)
}
\keyword{array}% at least one, from doc/KEYWORDS


\eof
\name{sseg}
\alias{sseg}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Position in a similarity vector}
\description{
  \code{sseg(i,j)} gives the position of the similarity of objects
  \code{i} and \code{j} in the similarity vectors produced by
  \code{fixreg} and \code{fixmahal}.
  \code{sseg} should only be used as an auxiliary function in
  \code{fixreg} and \code{fixmahal}.
}
\usage{
sseg(i, j)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{i}{positive integer.}
  \item{j}{positive integer.}
}
\value{A positive integer.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\examples{
sseg(3,4)
}
\keyword{utilities}% at least one, from doc/KEYWORDS
\eof
\name{tdecomp}
\alias{tdecomp}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Root of singularity-corrected eigenvalue decomposition}
\description{
  Computes transposed eigenvectors of matrix \code{m} times diagonal of
  square root of eigenvalues so that eigenvalues smaller than 1e-6 are
  set to 1e-6.
}
\usage{
tdecomp(m)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{m}{a symmetric matrix of minimum format 2*2.}
}
\details{
  Thought for use in \code{discrcoord} only.}
\value{
  a matrix.
}
\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}
}
\note{
  Thought for use within \code{\link{discrcoord}} only.
}

\examples{
x <- rnorm(10)
y <- rnorm(10)
z <- cov(cbind(x,y))
tdecomp(z)
}
\keyword{array}% at least one, from doc/KEYWORDS

\eof
\name{tonedata}
\alias{tonedata}
\title{Tone perception data}
\description{
  The tone perception data stem
  from an experiment of Cohen (1980) and have been analyzed in de Veaux
  (1989).
  A pure fundamental tone was played to a
  trained musician. Electronically generated overtones were added, determined 
  by a stretching ratio of \code{stretchratio}. \code{stretchratio=2.0}
  corresponds to the harmonic pattern
  usually heard in traditional definite pitched instruments. The musician was
  asked to tune an adjustable tone to the octave above the fundamental tone.
  \code{tuned} gives the ratio of the adjusted tone to the fundamental,
  i.e. \code{tuned=2.0} would be the correct tuning for all
  \code{stretchratio}-values.
  The data analyzed here belong to 150 trials 
  with the same musician. In the original study, there were four further
  musicians. 
}
\usage{data(tonedata)}
\format{A data frame with 2 variables \code{stretchratio} and
  \code{tuned} and 150 cases.}
\source{Cohen, E. A. (1980) \emph{Inharmonic tone
    perception}. Unpublished Ph.D. dissertation, Stanford University}
\references{
  de Veaux, R. D. (1989) Mixtures of Linear Regressions,
  \emph{Computational Statistics and Data Analysis} 8, 227-245.
}
\keyword{datasets}
\eof
\name{wfu}
\alias{wfu}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Weight function (for Mahalabobis distances)}
\description{
  Function of the elements of \code{md}, which is 1 for arguments smaller
  than \code{ca}, 0 for arguments larger than \code{ca2} and linear
  (default: continuous) in between.
  
  Thought for use in \code{fixmahal}.
}
\usage{
wfu(md, ca, ca2, a1 = 1/(ca - ca2), a0 = -a1 * ca2)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{md}{vector of positive numericals.}
  \item{ca}{positive numerical.}
  \item{ca2}{positive numerical.}
  \item{a1}{numerical. Slope.}
  \item{a0}{numerical. Intercept.}
}

\value{
  A vector of numericals between 0 and 1.
}

\author{Christian Hennig
  \email{hennig@math.uni-hamburg.de}
  \url{http://www.math.uni-hamburg.de/home/hennig/}}

\seealso{\code{\link{fixmahal}}}

\examples{
  md <- seq(0,10,by=0.1)
  wfu(md,ca=5,ca2=8)
}
\keyword{arith}% at least one, from doc/KEYWORDS







\eof
